import 'package:flutter/material.dart';
import 'package:video_player/video_player.dart';


/// The video overlay widget. This widget is used to display the play, pause button,
/// back button and black overlay background.
class VideoOverlay extends StatelessWidget {
  const VideoOverlay(
      {super.key,
      required this.controller,
      required this.onPlayPressed,
      required this.isPortrait,
      this.overlayColor,
      this.backIcon,
      this.onBackButtonPressed,
      this.backButtonColor,
      this.iconSize,
      this.iconColor});

  final VideoPlayerController controller;
  final void Function() onPlayPressed;
  final bool isPortrait;
  final Color? overlayColor;
  final void Function()? onBackButtonPressed;
  final Icon? backIcon;
  final Color? backButtonColor;
  final double? iconSize;
  final Color? iconColor;

  @override
  Widget build(BuildContext context) {
    return Stack(children: [
      Positioned.fill(
        child: Container(color: overlayColor ?? Colors.black26),
      ),
      Container(
          child: !isPortrait
              ? IconButton(
                  onPressed:
                      onBackButtonPressed ?? () => Navigator.pop(context),
                  icon: backIcon ?? const Icon(Icons.arrow_back),
                  color: backButtonColor ?? Colors.white)
              : null),
      Center(
          child: IconButton(
              icon: Icon(
                  controller.value.isPlaying ? Icons.pause : Icons.play_arrow),
              iconSize: iconSize ?? 50,
              color: iconColor ?? Colors.white,
              onPressed: onPlayPressed))
    ]);
  }
}
